==> benchling-api-client-0.11.1a0.tar.gz: benchling-api-client-0.11.1a0/benchling_api_client/models/dropdown_option.py <==
from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..models.dropdown_option_archive_record import DropdownOptionArchiveRecord
from ..types import UNSET, Unset

T = TypeVar("T", bound="DropdownOption")


@attr.s(auto_attribs=True)
class DropdownOption:
    """  """

    name: Union[Unset, str] = UNSET
    id: Union[Unset, str] = UNSET
    archive_record: Union[Unset, None, DropdownOptionArchiveRecord] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        id = self.id
        archive_record: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.archive_record, Unset):
            archive_record = self.archive_record.to_dict() if self.archive_record else None

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if name is not UNSET:
            field_dict["name"] = name
        if id is not UNSET:
            field_dict["id"] = id
        if archive_record is not UNSET:
            field_dict["archiveRecord"] = archive_record

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name", UNSET)

        id = d.pop("id", UNSET)

        archive_record = None
        _archive_record = d.pop("archiveRecord", UNSET)
        if _archive_record is not None and not isinstance(_archive_record, Unset):
            archive_record = DropdownOptionArchiveRecord.from_dict(_archive_record)

        dropdown_option = cls(
            name=name,
            id=id,
            archive_record=archive_record,
        )

        return dropdown_option

==> benchling-api-client-0.12.0a0.tar.gz: benchling-api-client-0.12.0a0/benchling_api_client/models/dropdown_option.py <==
from typing import Any, Dict, Union

import attr

from ..models.dropdown_option_archive_record import DropdownOptionArchiveRecord
from ..types import UNSET, Unset


@attr.s(auto_attribs=True)
class DropdownOption:
    """  """

    id: str
    name: Union[Unset, str] = UNSET
    archive_record: Union[Unset, None, DropdownOptionArchiveRecord] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        name = self.name
        archive_record: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.archive_record, Unset):
            archive_record = self.archive_record.to_dict() if self.archive_record else None

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "id": id,
            }
        )
        if name is not UNSET:
            field_dict["name"] = name
        if archive_record is not UNSET:
            field_dict["archiveRecord"] = archive_record

        return field_dict

    @staticmethod
    def from_dict(src_dict: Dict[str, Any]) -> "DropdownOption":
        d = src_dict.copy()
        id = d.pop("id")

        name = d.pop("name", UNSET)

        archive_record = None
        _archive_record = d.pop("archiveRecord", UNSET)
        if _archive_record is not None and not isinstance(_archive_record, Unset):
            archive_record = DropdownOptionArchiveRecord.from_dict(_archive_record)

        dropdown_option = DropdownOption(
            id=id,
            name=name,
            archive_record=archive_record,
        )

        return dropdown_option
